/* gtkspell - a spell-checking addon for GTK's TextView widget
 * Copyright (c) 2002 Evan Martin.
 */

/* vim: set ts=4 sw=4 wm=5 : */

#include <gtk/gtk.h>
#include <pspell/pspell.h>
#include "spell.h"

/* in theory, this file could be replaced by a file that provided the same
 * functions but didn't use pspell internally. */


/* we keep around one pspell instance for everything.
 * we don't need any per-textview-data.
 * could this cause some extra possible thread-related bugs? */
static PspellManager *manager = 0;

void*
spell_suggestions_begin(const char *word) {
	/* begin the suggestions process.  return an opaque void pointer. */
	const PspellWordList *suggestions;
	PspellStringEmulation *elements;
	suggestions = pspell_manager_suggest(manager, word, -1);
	elements = pspell_word_list_elements(suggestions);
	return (void*)elements;
}

const char*
spell_suggestions_next(void *data) {
	PspellStringEmulation *elements = data;
	return pspell_string_emulation_next(elements);
}

void
spell_suggestions_end(void *data) {
	PspellStringEmulation *elements = data;
	delete_pspell_string_emulation(elements);
}

int
gtkspell_init() {
	PspellConfig *config = new_pspell_config();
	PspellCanHaveError *err;

	pspell_config_replace(config, "language-tag", "en_US"); /* FIXME */
	err = new_pspell_manager(config);
	if (pspell_error_number(err) != 0) {
		g_warning("pspell: %s\n", pspell_error_message(err));
		return -1;
	} 
	manager = to_pspell_manager(err);
	return 0;
}

int
spell_check_word(char *word, int size) {
	return pspell_manager_check(manager, word, size);
}

